@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: socket_sending_communicator.c,v $ $Revision: 1.14 $ $Date: 2009/01/31 16:06:29 $ $Author: christian $
+ * @version $RCSfile: socket_sending_communicator.c,v $ $Revision: 1.14 $ $Date: 2009-01-31 16:06:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,22 +27,26 @@
 #define SOCKET_SENDING_COMMUNICATOR_SOURCE
 
 //?? TEST for test file; DELETE later!
-#include <fcntl.h>
 #include <sys/stat.h>
+#include <fcntl.h>
+//?? TEST END
 
 #include <netinet/in.h>
 #include <sys/socket.h>
 #include "../../../applicator/maintainer/starting/socket_starting_maintainer.c"
 #include "../../../constant/abstraction/cybol/text_cybol_abstraction.c"
+#include "../../../constant/abstraction/memory/primitive_memory_abstraction.c"
 #include "../../../constant/model/cybol/communication_mode_cybol_model.c"
 #include "../../../constant/model/cybol/http_request_cybol_model.c"
 #include "../../../constant/model/log/message_log_model.c"
 #include "../../../constant/model/memory/integer_memory_model.c"
 #include "../../../constant/model/memory/pointer_memory_model.c"
+#include "../../../executor/communicator/sender/datagram_socket_sender.c"
+#include "../../../executor/communicator/sender/raw_socket_sender.c"
+#include "../../../executor/communicator/sender/stream_socket_sender.c"
+#include "../../../executor/converter/encoder.c"
 #include "../../../logger/logger.c"
-#include "../../../memoriser/communicator/datagram_socket_communicator.c"
-#include "../../../memoriser/communicator/raw_socket_communicator.c"
-#include "../../../memoriser/communicator/stream_socket_communicator.c"
+#include "../../../variable/type_size/socket_type_size.c"
 
 /**
  * Gets the socket for server mode.
@@ -50,7 +54,7 @@
  * Server mode means that this system was asked by a client system,
  * that it now needs to reply to.
  *
- * @param p0 the socket of this system (Hand over as reference!)
+ * @param p0 the communication partner socket (Hand over as reference!)
  * @param p1 the internal memory
  * @param p2 the base internal
  */
@@ -64,21 +68,21 @@ void communicate_sending_socket_get_socket_server_mode(void* p0, void* p1, void*
 
         // The internal memory index.
         int i = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
-        // The socket mutex.
-        pthread_mutex_t** mt = (pthread_mutex_t**) NULL_POINTER_MEMORY_MODEL;
+
+        // Get communication partner socket.
+        i = *base + *SOCKET_COMMUNICATION_PARTNER_INTERNAL_MEMORY_MEMORY_NAME;
+        get(p0, p1, (void*) &i, (void*) POINTER_MEMORY_ABSTRACTION, (void*) POINTER_MEMORY_ABSTRACTION_COUNT);
 
 /*??
         ONLY necessary when writing or deleting a socket from internal memory.
-        This may become necessary if many sockets are hold in a queue, soon to be implemented.
+        This may become necessary if many sockets are held in a queue.
+
+        // The socket mutex.
+        pthread_mutex_t** mt = (pthread_mutex_t**) NULL_POINTER_MEMORY_MODEL;
 
         // Get socket mutex.
         i = *base + *SOCKET_MUTEX_INTERNAL_MEMORY_MEMORY_NAME;
-        get_element(p1, (void*) &i, (void*) &mt, (void*) POINTER_VECTOR_MEMORY_ABSTRACTION, (void*) POINTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-*/
-/*??
-        // Get communication partner socket.
-        i = *base + *SOCKET_COMMUNICATION_PARTNER_INTERNAL_MEMORY_MEMORY_NAME;
-        get_element(p1, (void*) &i, p0, (void*) POINTER_VECTOR_MEMORY_ABSTRACTION, (void*) POINTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+        get((void*) &mt, p1, (void*) &i, (void*) POINTER_MEMORY_ABSTRACTION, (void*) POINTER_MEMORY_ABSTRACTION_COUNT);
 */
 
     } else {
@@ -182,7 +186,7 @@ void communicate_sending_socket_get_socket_client_mode(void* p0, void* p1, void*
  * In server mode, an existing socket of this system is read from the internal memory.
  * In client mode, a completely new socket is created.
  *
- * @param p0 the socket of this system (Hand over as reference!)
+ * @param p0 the communication partner socket (Hand over as reference!)
  * @param p1 the internal memory
  * @param p2 the base internal
  * @param p3 the socket namespace
@@ -199,7 +203,7 @@ void communicate_sending_socket_get_socket(void* p0, void* p1, void* p2, void* p
 
     if (r == *NUMBER_0_INTEGER_MEMORY_MODEL) {
 
-        compare_arrays(p5, p6, (void*) SERVER_COMMUNICATION_MODE_CYBOL_MODEL, (void*) SERVER_COMMUNICATION_MODE_CYBOL_MODEL_COUNT, (void*) &r, (void*) WIDE_CHARACTER_ARRAY_MEMORY_ABSTRACTION);
+        compare_equal_arrays((void*) &r, p5, p6, (void*) SERVER_COMMUNICATION_MODE_CYBOL_MODEL, (void*) SERVER_COMMUNICATION_MODE_CYBOL_MODEL_COUNT, (void*) WIDE_CHARACTER_PRIMITIVE_MEMORY_ABSTRACTION);
 
         if (r != *NUMBER_0_INTEGER_MEMORY_MODEL) {
 
@@ -209,7 +213,7 @@ void communicate_sending_socket_get_socket(void* p0, void* p1, void* p2, void* p
 
     if (r == *NUMBER_0_INTEGER_MEMORY_MODEL) {
 
-        compare_arrays(p5, p6, (void*) CLIENT_COMMUNICATION_MODE_CYBOL_MODEL, (void*) CLIENT_COMMUNICATION_MODE_CYBOL_MODEL_COUNT, (void*) &r, (void*) WIDE_CHARACTER_ARRAY_MEMORY_ABSTRACTION);
+        compare_equal_arrays((void*) &r, p5, p6, (void*) CLIENT_COMMUNICATION_MODE_CYBOL_MODEL, (void*) CLIENT_COMMUNICATION_MODE_CYBOL_MODEL_COUNT, (void*) WIDE_CHARACTER_PRIMITIVE_MEMORY_ABSTRACTION);
 
         if (r != *NUMBER_0_INTEGER_MEMORY_MODEL) {
 
@@ -244,7 +248,7 @@ void communicate_sending_socket_set_nonblocking_mode(void* p0) {
         // need to be considered and their file descriptors handed over as
         // parameter.
         // A simple "sleep" procedure is considered to be a more simple and
-        // clean solution here.
+        // clean solution here. See file "controller/checker/wait_checker.c"!
 
         // Get file status flags.
         int fl = fcntl(*s, F_GETFL, NUMBER_0_INTEGER_MEMORY_MODEL);
@@ -264,7 +268,7 @@ void communicate_sending_socket_set_nonblocking_mode(void* p0) {
 
     } else {
 
-        log_terminated_message((void*) ERROR_LEVEL_LOG_MODEL, (void*) L"Could not send message via socket. The base internal is null.");
+        log_terminated_message((void*) ERROR_LEVEL_LOG_MODEL, (void*) L"Could not send socket / set non-blocking mode. The base internal is null.");
     }
 }
 
@@ -290,12 +294,12 @@ void communicate_sending_socket_allocate_host_address(void* p0, void* p1) {
             if (*n == AF_INET) {
 
                 // Allocate ipv4 socket address.
-                *a = malloc(sizeof(struct in_addr));
+                *a = malloc(*INTERNET_PROTOCOL_4_HOST_ADDRESS_SOCKET_TYPE_SIZE);
 
             } else if (*n == AF_INET6) {
 
                 // Allocate ipv6 socket address.
-                *a = malloc(sizeof(struct in6_addr));
+                *a = malloc(*INTERNET_PROTOCOL_6_HOST_ADDRESS_SOCKET_TYPE_SIZE);
             }
 
         } else {
@@ -352,7 +356,7 @@ void communicate_sending_socket_allocate_socket_address(void* p0, void* p1, void
                     // With the known type "short int" of the "sun_family" field and
                     // a fixed size "108" of the "sun_path" field, the overall size of
                     // the "sockaddr_un" structure can be calculated as sum.
-                    *as = sizeof(short int) + *NUMBER_108_INTEGER_MEMORY_MODEL;
+                    *as = *SIGNED_SHORT_INTEGER_INTEGRAL_TYPE_SIZE + *NUMBER_108_INTEGER_MEMORY_MODEL;
 
                     // Allocate socket address.
                     *a = malloc(*as);
@@ -360,7 +364,7 @@ void communicate_sending_socket_allocate_socket_address(void* p0, void* p1, void
                 } else if (*n == AF_INET) {
 
                     // Initialise ipv4 socket address size.
-                    *as = sizeof(struct sockaddr_in);
+                    *as = *INTERNET_PROTOCOL_4_SOCKET_ADDRESS_SOCKET_TYPE_SIZE;
 
                     // Allocate ipv4 socket address.
                     *a = malloc(*as);
@@ -368,7 +372,7 @@ void communicate_sending_socket_allocate_socket_address(void* p0, void* p1, void
                 } else if (*n == AF_INET6) {
 
                     // Initialise ipv6 socket address size.
-                    *as = sizeof(struct sockaddr_in6);
+                    *as = *INTERNET_PROTOCOL_6_SOCKET_ADDRESS_SOCKET_TYPE_SIZE;
 
                     // Allocate ipv6 socket address.
                     *a = malloc(*as);
@@ -476,79 +480,9 @@ void communicate_sending_socket(void* p0, void* p1, void* p2, void* p3,
     void* p4, void* p5, void* p6, void* p7, void* p8, void* p9, void* p10,
     void* p11, void* p12, void* p13, void* p14, void* p15, void* p16, void* p17, void* p18, void* p19, void* p20) {
 
-    log_terminated_message((void*) INFORMATION_LEVEL_LOG_MODEL, (void*) L"Send message via socket.");
-
-    // The communication style.
-    int st = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
-    // The socket namespace.
-    int sn = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
-    // The address namespace.
-    int an = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
-    // The socket of this system.
-    int** s = (int**) NULL_POINTER_MEMORY_MODEL;
-    // The host address of the communication partner.
-    void* ha = *NULL_POINTER_MEMORY_MODEL;
-    // The socket address of the communication partner.
-    void* sa = *NULL_POINTER_MEMORY_MODEL;
-    int sas = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    // The http body character vector as encoded (serialised) model.
-    void* b = *NULL_POINTER_MEMORY_MODEL;
-    int bc = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    int bs = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    // The http message character vector to be sent to the socket.
-    void* m = *NULL_POINTER_MEMORY_MODEL;
-    int mc = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    int ms = *NUMBER_0_INTEGER_MEMORY_MODEL;
-
-/*??
-    // Get socket- and address namespace.
-    maintain_starting_socket_memorise_getting_namespace((void*) &sn, (void*) &an, p5, p6);
-*/
-    // Get socket communication style.
-    maintain_starting_socket_get_style((void*) &st, p7, p8);
-/*??
-    // Get socket.
-    communicate_sending_socket_get_socket((void*) &s, p0, p1, (void*) &sn, (void*) &st, p9, p10);
-
-    fwprintf(stdout, L"TEST: send socket: %i \n", **s);
-*/
-
-    // Set non-blocking mode for socket.
-//??    communicate_sending_socket_set_nonblocking_mode((void*) *s);
-
-/*??
-    // Allocate host address.
-    communicate_sending_socket_allocate_host_address((void*) &ha, (void*) &an);
-    // Allocate socket address.
-    communicate_sending_socket_allocate_socket_address((void*) &sa, (void*) &sas, (void*) &an);
-*/
-    // Allocate http body character vector.
-    allocate((void*) &b, (void*) &bs, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    // Allocate http message character vector.
-    allocate((void*) &m, (void*) &ms, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-
-/*??
-    // Initialise host address.
-    maintain_starting_socket_get_host_address(ha, p2, p3, (void*) &an);
-    // Initialise socket address.
-    communicate_sending_socket_initialise_socket_address((void*) &sa, p2, p3, ha, p4, (void*) &an);
-*/
-
-    // Encode http body.
-    //
-    // The compound model is encoded depending on the given language, e.g. into xhtml format.
-    encode((void*) &b, (void*) &bc, (void*) &bs, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL, p11, p12, p13, p14, p15, p16, p17, p18, p19, p20);
-
-    // Encode http response.
-    encode((void*) &m, (void*) &mc, (void*) &ms, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL,
-        b, (void*) &bc, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL,
-        *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL, (void*) HTTP_RESPONSE_MESSAGE_CYBOL_ABSTRACTION, (void*) HTTP_RESPONSE_MESSAGE_CYBOL_ABSTRACTION_COUNT);
-
-    log_write_terminated_message(stdout, L"SUCCESS! Generated http message with xhtml file as body.\n");
-
-//?? -- START TEST
+    //?? --- START TEST ---
     // The log file name.
-    char* n = "send.xhtml";
+    char* n = "http_response";
     // The log file status flags.
     int status = O_TRUNC | O_CREAT | O_WRONLY;
     // The log file.
@@ -573,21 +507,66 @@ void communicate_sending_socket(void* p0, void* p1, void* p2, void* p3,
         // Set file access rights.
         chmod(n, r);
 
-        // Log xhtml to output.
-        write(f, m, mc);
+        // Log html to output.
+        write(f, p13, *((int*) p14));
 
     } else {
 
         // CAUTION! DO NOT use logging functionality here!
         // The logger will not work before these global variables are set.
-        log_write_terminated_message(stdout, L"Error: Could open xhtml log file. A file error occured.\n");
+        log_write_terminated_message(stdout, L"Error: Could not open socket sending http_response file. A file error occured.\n");
     }
-//?? -- END TEST
+    //?? --- END TEST ---
+
+    log_terminated_message((void*) INFORMATION_LEVEL_LOG_MODEL, (void*) L"Send message via socket.");
+
+    // The communication style.
+    int st = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
+    // The socket namespace.
+    int sn = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
+    // The address namespace.
+    int an = *NUMBER_MINUS_1_INTEGER_MEMORY_MODEL;
+    // The communication partner socket.
+    int** s = (int**) NULL_POINTER_MEMORY_MODEL;
+    // The host address of the communication partner.
+    void* ha = *NULL_POINTER_MEMORY_MODEL;
+    // The socket address of the communication partner.
+    void* sa = *NULL_POINTER_MEMORY_MODEL;
+    int sas = *NUMBER_0_INTEGER_MEMORY_MODEL;
+
+    // Get socket- and address namespace.
+    maintain_starting_socket_memorise_getting_namespace((void*) &sn, (void*) &an, p5, p6);
+    fwprintf(stdout, L"TEST: send socket sn: %i \n", sn);
+    fwprintf(stdout, L"TEST: send socket an: %i \n", an);
+    // Get socket communication style.
+    maintain_starting_socket_get_style((void*) &st, p7, p8);
+    fwprintf(stdout, L"TEST: send socket st: %i \n", st);
+    // Get communication partner socket.
+    communicate_sending_socket_get_socket((void*) &s, p0, p1, (void*) &sn, (void*) &st, p9, p10);
+    fwprintf(stdout, L"TEST: send socket s: %i \n", **s);
+
+    // Set non-blocking mode for socket.
+    communicate_sending_socket_set_nonblocking_mode((void*) *s);
+    fwprintf(stdout, L"TEST: send socket s non-blocking: %i \n", **s);
+
+    // Allocate host address.
+    communicate_sending_socket_allocate_host_address((void*) &ha, (void*) &an);
+    fwprintf(stdout, L"TEST: send socket ha: %i \n", ha);
+    // Allocate socket address.
+    communicate_sending_socket_allocate_socket_address((void*) &sa, (void*) &sas, (void*) &an);
+    fwprintf(stdout, L"TEST: send socket sa: %i \n", sa);
+
+    // Initialise host address.
+    maintain_starting_socket_get_host_address(ha, p2, p3, (void*) &an);
+    fwprintf(stdout, L"TEST: send socket ha init: %i \n", ha);
+    // Initialise socket address.
+    communicate_sending_socket_initialise_socket_address((void*) &sa, p2, p3, ha, p4, (void*) &an);
+    fwprintf(stdout, L"TEST: send socket sa init: %i \n", sa);
 
     // One might think that a deadlock may occur if this system
     // sends a message to itself. However, this could only occur if
     // the socket of this system got locked when a message is sent
-    // AND ALSO when a message is received. Once the lock is set by
+    // AND ALSO when a message is received. Once the lock got set by
     // the "send" procedure, the "receive" procedure would wait
     // endlessly for an unlock, since the "send" in turn would wait
     // for the "receive" procedure to finish.
@@ -599,35 +578,20 @@ void communicate_sending_socket(void* p0, void* p1, void* p2, void* p3,
     // identical. As a consequence, socket locking using a mutex is
     // not necessary here!
 
-/*??
     // Send message via socket in server mode.
-    //?? TEST: For testing reasons, the internal memory parameter p0 is misused as client socket here!
-    write_socket(p0, m, (void*) &mc, *NULL_POINTER_MEMORY_MODEL, *NULL_POINTER_MEMORY_MODEL, p9, p10, (void*) &st);
-*/
-
-    // Send message via socket in client mode.
-//??    write_socket((void*) *s, m, (void*) &mc, (void*) &sa, (void*) &sas, p9, p10, (void*) &st);
+    send_stream_socket((void*) *s, p13, p14, (void*) &sa, (void*) &sas, p9, p10);
 
     // Close socket.
     //
     // CAUTION! The socket is always closed, no matter whether it was created in:
-    // - this "send_socket" operation (client mode)
-    // - the "receive_socket" operation (server mode) and retrieved from internal memory here
-//??    close(**s);
-    //?? TEST: temporary as long as p0 is used as client socket parameter!
-    close(*((int*) p0));
+    // - this "send_socket" operation right here (client mode)
+    // - the "receive_socket" operation (server mode) and retrieved from internal memory right here
+    close(**s);
 
-    // Deallocate http body character vector.
-    deallocate((void*) &b, (void*) &bs, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    // Deallocate http message character vector.
-    deallocate((void*) &m, (void*) &ms, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-
-/*??
     // Deallocate socket address.
     free(sa);
     // Deallocate host address.
     free(ha);
-*/
 }
 
 /* SOCKET_SENDING_COMMUNICATOR_SOURCE */
