@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: cyboi.c,v $ $Revision: 1.46 $ $Date: 2009/01/31 16:06:30 $ $Author: christian $
+ * @version $RCSfile: cyboi.c,v $ $Revision: 1.47 $ $Date: 2009-10-06 21:25:26 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,6 +27,7 @@
 #define CYBOI_SOURCE
 
 #include <string.h>
+
 #include "../constant/model/cyboi/operation_mode_cyboi_model.c"
 #include "../constant/model/log/message_log_model.c"
 #include "../constant/model/memory/integer_memory_model.c"
@@ -38,14 +39,13 @@
 #include "../controller/optionaliser.c"
 #include "../controller/orienter.c"
 #include "../controller/tester.c"
+#include "../controller/unglobaliser.c"
 #include "../variable/log_setting.c"
 
-#include "../memoriser/converter/xml_converter.c"
-
 //
 // This is the main file of the Cybernetics Oriented Interpreter (CYBOI).
 // CYBOI can interpret Cybernetics Oriented Language (CYBOL) files,
-// which adhere to the Extended Markup Language (XML) syntax.
+// which adhere to the Extensible Markup Language (XML) syntax.
 //
 
 /**
@@ -64,11 +64,13 @@
 int main(int p0, char** p1) {
 
     // One note about dynamic memory allocation:
-    // There is no point in freeing blocks at the end of a program, because all
-    // of the program's space is given back to the system when the process terminates.
+    // There is no point in freeing blocks at the end of an application programme,
+    // because all of the programme's space is given back to the operating system
+    // when the process terminates.
     // Of course, all dynamically allocated memory should also be freed properly.
-    // However, if some memory to be freed is forgotten, it will not harm
-    // the operating system, as it will be freed automatically on process shutdown.
+    // However, if some memory to be freed is forgotten accidentally, it will
+    // not harm the operating system, as the memory occupied by the application
+    // will be freed automatically on process shutdown.
     //
     // TODO: YET TO ANSWER: How is that with forgotten threads?
     // Are they killed automatically when a process is shut down?
@@ -151,7 +153,7 @@ int main(int p0, char** p1) {
         int ks = *NUMBER_0_INTEGER_MEMORY_MODEL;
 
         // Allocate cybol knowledge file path.
-        allocate((void*) &k, (void*) &ks, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+        allocate((void*) &k, (void*) &ks, (void*) WIDE_CHARACTER_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_MEMORY_ABSTRACTION_COUNT);
 
         // Optionalise command line argument options.
         optionalise((void*) &m, (void*) &k, (void*) &kc, (void*) &ks, (void*) LOG_LEVEL, (void*) &LOG_OUTPUT, (void*) p1, (void*) &p0);
@@ -207,7 +209,7 @@ int main(int p0, char** p1) {
         deoptionalise((void*) &LOG_OUTPUT);
 
         // Deallocate cybol knowledge file path.
-        deallocate((void*) &k, (void*) &ks, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+        deallocate((void*) &k, (void*) &ks, (void*) WIDE_CHARACTER_MEMORY_ABSTRACTION, (void*) WIDE_CHARACTER_MEMORY_ABSTRACTION_COUNT);
 
         // Shutdown global variables.
         unglobalise();
