@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: compound_handler.c,v $ $Revision: 1.34 $ $Date: 2009/01/31 16:31:28 $ $Author: christian $
+ * @version $RCSfile: compound_handler.c,v $ $Revision: 1.34 $ $Date: 2009-01-31 16:31:28 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,12 +27,13 @@
 #define COMPOUND_HANDLER_SOURCE
 
 #include "../../constant/abstraction/memory/memory_abstraction.c"
+#include "../../constant/abstraction/memory/primitive_memory_abstraction.c"
 #include "../../constant/model/log/message_log_model.c"
 #include "../../constant/model/memory/integer_memory_model.c"
 #include "../../constant/model/memory/pointer_memory_model.c"
 #include "../../constant/name/memory/compound_memory_name.c"
+#include "../../executor/comparator/array_equality_comparator.c"
 #include "../../logger/logger.c"
-#include "../../memoriser/array.c"
 
 //
 // Forward declarations.
@@ -82,12 +83,12 @@ void handle_compound_part(void* p0, void* p1, void* p2, void* p3, void* p4, void
     void** pdc = NULL_POINTER_MEMORY_MODEL;
 
     // Get abstractions, models, details.
-    get_array_elements(p10, (void*) ABSTRACTIONS_COMPOUND_MEMORY_NAME, (void*) &pa, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-    get_array_elements(p10, (void*) ABSTRACTIONS_COUNTS_COMPOUND_MEMORY_NAME, (void*) &pac, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-    get_array_elements(p10, (void*) MODELS_COMPOUND_MEMORY_NAME, (void*) &pm, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-    get_array_elements(p10, (void*) MODELS_COUNTS_COMPOUND_MEMORY_NAME, (void*) &pmc, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-    get_array_elements(p10, (void*) DETAILS_COMPOUND_MEMORY_NAME, (void*) &pd, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-    get_array_elements(p10, (void*) DETAILS_COUNTS_COMPOUND_MEMORY_NAME, (void*) &pdc, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pa, p10, (void*) ABSTRACTIONS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pac, p10, (void*) ABSTRACTIONS_COUNTS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pm, p10, (void*) MODELS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pmc, p10, (void*) MODELS_COUNTS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pd, p10, (void*) DETAILS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+    get_array_elements((void*) &pdc, p10, (void*) DETAILS_COUNTS_COMPOUND_MEMORY_NAME, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
 
     if (*pa != *NULL_POINTER_MEMORY_MODEL) {
 
@@ -112,12 +113,12 @@ void handle_compound_part(void* p0, void* p1, void* p2, void* p3, void* p4, void
                             void** dc = NULL_POINTER_MEMORY_MODEL;
 
                             // Get abstraction, model, details.
-                            get_array_elements(*pa, p15, (void*) &a, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-                            get_array_elements(*pac, p15, (void*) &ac, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-                            get_array_elements(*pm, p15, (void*) &m, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-                            get_array_elements(*pmc, p15, (void*) &mc, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-                            get_array_elements(*pd, p15, (void*) &d, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
-                            get_array_elements(*pdc, p15, (void*) &dc, (void*) POINTER_ARRAY_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &a, *pa, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &ac, *pac, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &m, *pm, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &mc, *pmc, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &d, *pd, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
+                            get_array_elements((void*) &dc, *pdc, p15, (void*) POINTER_PRIMITIVE_MEMORY_ABSTRACTION);
 
                             // Add part model (signal) to memory, using the whole signal's priority.
                             // (Each signal has a priority. A signal may consist of part
@@ -140,7 +141,7 @@ void handle_compound_part(void* p0, void* p1, void* p2, void* p3, void* p4, void
                                 // Lock signal memory mutex.
                                 pthread_mutex_lock(*mt);
 
-                                set_signal(p4, p5, p6, a, ac, m, mc, d, dc, p12, p13);
+                                replace_signal_memory(p4, p5, p6, a, ac, m, mc, d, dc, p12, p13);
 
                                 // Set interrupt request flag, in order to notify the signal checker
                                 // that a new signal has been placed in the signal memory.
