@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: operation_handler.c,v $ $Revision: 1.57 $ $Date: 2009/01/31 16:06:31 $ $Author: christian $
+ * @version $RCSfile: operation_handler.c,v $ $Revision: 1.58 $ $Date: 2009-02-08 13:04:30 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -36,8 +36,8 @@
 #include "../../controller/handler/operation/lifecycle_operation_handler.c"
 #include "../../controller/handler/operation/memory_operation_handler.c"
 #include "../../controller/handler/operation/run_operation_handler.c"
+#include "../../executor/comparator/array_equality_comparator.c"
 #include "../../logger/logger.c"
-#include "../../memoriser/array.c"
 
 /**
  * Handles the operation signal.
@@ -65,14 +65,14 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
     log_terminated_message((void*) INFORMATION_LEVEL_LOG_MODEL, (void*) L"\n\n");
     log_message((void*) INFORMATION_LEVEL_LOG_MODEL, (void*) HANDLE_OPERATION_MESSAGE_LOG_MODEL, (void*) HANDLE_OPERATION_MESSAGE_LOG_MODEL_COUNT);
 
+    log_terminated_message((void*) DEBUG_LEVEL_LOG_MODEL, p10);
+    log_terminated_message((void*) DEBUG_LEVEL_LOG_MODEL, (void*) L"\n");
+
 /*??
     fwprintf(stdout, L"TEST handle operation count: %i\n", *((int*) p11));
     fwprintf(stdout, L"TEST handle operation: %ls\n", (wchar_t*) p10);
 */
 
-    log_terminated_message((void*) DEBUG_LEVEL_LOG_MODEL, p10);
-    log_terminated_message((void*) DEBUG_LEVEL_LOG_MODEL, (void*) L"\n");
-
     // The comparison result.
     int r = *NUMBER_0_INTEGER_MEMORY_MODEL;
 
