@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: manager.c,v $ $Revision: 1.55 $ $Date: 2009/01/31 16:06:31 $ $Author: christian $
+ * @version $RCSfile: manager.c,v $ $Revision: 1.56 $ $Date: 2009-10-06 21:25:26 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,16 +27,23 @@
 #define MANAGER_SOURCE
 
 #include <pthread.h>
+#include <signal.h>
+#include "../constant/channel/cybol_channel.c"
+#include "../constant/model/log/message_log_model.c"
+#include "../constant/model/memory/double_memory_model.c"
+#include "../constant/model/memory/integer_memory_model.c"
+#include "../constant/model/memory/pointer_memory_model.c"
 #include "../controller/manager/internal_memory_manager.c"
 #include "../controller/manager/system_signal_handler_manager.c"
 #include "../controller/checker.c"
 #include "../controller/initialiser.c"
-#include "../constant/channel/cybol_channel.c"
-#include "../constant/model/memory/integer_memory_model.c"
-#include "../constant/model/log/message_log_model.c"
-#include "../constant/model/memory/pointer_memory_model.c"
+#include "../executor/memoriser/allocator/model_allocator.c"
+#include "../executor/memoriser/deallocator/model_deallocator.c"
 #include "../logger/logger.c"
-#include "../memoriser/allocator.c"
+#include "../variable/type_size/integral_type_size.c"
+#include "../variable/type_size/real_type_size.c"
+#include "../variable/type_size/signal_type_size.c"
+#include "../variable/type_size/thread_type_size.c"
 
 /**
  * Manages the system.
@@ -71,13 +78,16 @@ void manage(void* p0, void* p1) {
 
     // The internal memory.
     void* i = *NULL_POINTER_MEMORY_MODEL;
-    int ic = *INTERNAL_MEMORY_MEMORY_MODEL_COUNT;
-    int is = *INTERNAL_MEMORY_MEMORY_MODEL_COUNT;
-
+    void* ic = *NULL_POINTER_MEMORY_MODEL;
+    void* is = *NULL_POINTER_MEMORY_MODEL;
     // The knowledge memory.
     void* k = *NULL_POINTER_MEMORY_MODEL;
-    int* kc = (int*) *NULL_POINTER_MEMORY_MODEL;
-    int* ks = (int*) *NULL_POINTER_MEMORY_MODEL;
+    void* kc = *NULL_POINTER_MEMORY_MODEL;
+    void* ks = *NULL_POINTER_MEMORY_MODEL;
+    // The signal memory.
+    void* s = *NULL_POINTER_MEMORY_MODEL;
+    void* sc = *NULL_POINTER_MEMORY_MODEL;
+    void* ss = *NULL_POINTER_MEMORY_MODEL;
 
     // A meta knowledge memory?
     // Theoretically, a meta knowledge memory could be created, too, and be
@@ -92,11 +102,6 @@ void manage(void* p0, void* p1) {
     // .resmedicinae#name                       --> name as meta knowledge about resmedicinae application
     // #something                               --> meta knowledge about knowledge root = nonsense
 
-    // The signal memory.
-    void* s = *NULL_POINTER_MEMORY_MODEL;
-    int* sc = (int*) *NULL_POINTER_MEMORY_MODEL;
-    int* ss = (int*) *NULL_POINTER_MEMORY_MODEL;
-
     //
     // The signal memory interrupt request flag.
     //
@@ -122,6 +127,48 @@ void manage(void* p0, void* p1) {
     // Both of these assumptions are true on all of the machines that the GNU C
     // library supports and on all known POSIX systems.
     //
+    // Why is the keyword "volatile" used here?
+    //
+    // In the following example, the code sets the value stored in "foo" to 0.
+    // It then starts to poll that value repeatedly until it changes to 255:
+    //
+    // static int foo;
+    // void bar(void) {
+    //     foo = 0;
+    //     while (foo != 255);
+    // }
+    //
+    // An optimizing compiler will notice that no other code can possibly
+    // change the value stored in "foo", and will assume that it will
+    // remain equal to "0" at all times. The compiler will therefore
+    // replace the function body with an infinite loop similar to this:
+    //
+    // void bar_optimized(void) {
+    //     foo = 0;
+    //     while (true);
+    // }
+    //
+    // However, foo might represent a location that can be changed
+    // by other elements of the computer system at any time,
+    // such as a hardware register of a device connected to the CPU.
+    // The above code would never detect such a change;
+    // without the "volatile" keyword, the compiler assumes that
+    // the current program is the only part of the system that could
+    // change the value (which is by far the most common situation).
+    //
+    // To prevent the compiler from optimising code as above,
+    // the "volatile" keyword is used:
+    //
+    // static volatile int foo;
+    // void bar (void) {
+    //     foo = 0;
+    //     while (foo != 255);
+    // }
+    //
+    // With this modification, the loop condition will not be optimised
+    // away, and the system will detect the change when it occurs.
+    //
+
     volatile sig_atomic_t* signal_memory_irq = (volatile sig_atomic_t*) *NULL_POINTER_MEMORY_MODEL;
     // The gnu/linux console interrupt request flag.
     volatile sig_atomic_t* gnu_linux_console_irq = (volatile sig_atomic_t*) *NULL_POINTER_MEMORY_MODEL;
@@ -158,61 +205,52 @@ void manage(void* p0, void* p1) {
     // Variable allocation.
     //
 
-    // The internal memory count and size do not have to be allocated,
-    // since they have fixed values that cannot be changed at runtime.
-    // Allocate knowledge memory count, size.
-    allocate((void*) &kc, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    allocate((void*) &ks, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    // Allocate signal memory count, size.
-    allocate((void*) &sc, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    allocate((void*) &ss, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+    // Allocate internal memory.
+    // CAUTION! The internal memory count and size are set to a
+    // pre-defined value given by the constant "INTERNAL_MEMORY_MEMORY_MODEL_COUNT".
+    allocate_model((void*) &i, (void*) &ic, (void*) &is, (void*) INTERNAL_MEMORY_MEMORY_MODEL_COUNT, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
+    // Allocate knowledge memory.
+    allocate_model((void*) &k, (void*) &kc, (void*) &ks, (void*) NUMBER_0_INTEGER_MEMORY_MODEL, (void*) COMPOUND_MEMORY_ABSTRACTION, (void*) COMPOUND_MEMORY_ABSTRACTION_COUNT);
+    // Allocate signal memory.
+    allocate_model((void*) &s, (void*) &sc, (void*) &ss, (void*) NUMBER_0_INTEGER_MEMORY_MODEL, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
 
     // Allocate signal memory interrupt request flag.
-    signal_memory_irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    signal_memory_irq = (volatile sig_atomic_t*) malloc(*VOLATILE_ATOMIC_SIGNAL_TYPE_SIZE);
     // Allocate gnu/linux console interrupt request flag.
-    gnu_linux_console_irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    gnu_linux_console_irq = (volatile sig_atomic_t*) malloc(*VOLATILE_ATOMIC_SIGNAL_TYPE_SIZE);
     // Allocate x window system interrupt request flag.
-    x_window_system_irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    x_window_system_irq = (volatile sig_atomic_t*) malloc(*VOLATILE_ATOMIC_SIGNAL_TYPE_SIZE);
     // Allocate www service interrupt request flag.
-    www_service_irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    www_service_irq = (volatile sig_atomic_t*) malloc(*VOLATILE_ATOMIC_SIGNAL_TYPE_SIZE);
     // Allocate cyboi service interrupt request flag.
-    cyboi_service_irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    cyboi_service_irq = (volatile sig_atomic_t*) malloc(*VOLATILE_ATOMIC_SIGNAL_TYPE_SIZE);
 
     // Allocate signal memory mutex.
-    signal_memory_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    signal_memory_mutex = (pthread_mutex_t*) malloc(*MUTEX_THREAD_TYPE_SIZE);
     // Allocate gnu/linux console mutex.
-    gnu_linux_console_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    gnu_linux_console_mutex = (pthread_mutex_t*) malloc(*MUTEX_THREAD_TYPE_SIZE);
     // Allocate x window system mutex.
-    x_window_system_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    x_window_system_mutex = (pthread_mutex_t*) malloc(*MUTEX_THREAD_TYPE_SIZE);
     // Allocate www service mutex.
-    www_service_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    www_service_mutex = (pthread_mutex_t*) malloc(*MUTEX_THREAD_TYPE_SIZE);
     // Allocate cyboi service mutex.
-    cyboi_service_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    cyboi_service_mutex = (pthread_mutex_t*) malloc(*MUTEX_THREAD_TYPE_SIZE);
 
     // Allocate signal memory sleep time.
-    signal_memory_sleep_time = (double*) malloc(*DOUBLE_PRIMITIVE_SIZE);
+    signal_memory_sleep_time = (double*) malloc(*DOUBLE_REAL_TYPE_SIZE);
     // Allocate gnu linux console sleep time.
-    gnu_linux_console_sleep_time = (double*) malloc(*DOUBLE_PRIMITIVE_SIZE);
+    gnu_linux_console_sleep_time = (double*) malloc(*DOUBLE_REAL_TYPE_SIZE);
     // Allocate x window system sleep time.
-    x_window_system_sleep_time = (double*) malloc(*DOUBLE_PRIMITIVE_SIZE);
+    x_window_system_sleep_time = (double*) malloc(*DOUBLE_REAL_TYPE_SIZE);
     // Allocate www service sleep time.
-    www_service_sleep_time = (double*) malloc(*DOUBLE_PRIMITIVE_SIZE);
+    www_service_sleep_time = (double*) malloc(*DOUBLE_REAL_TYPE_SIZE);
     // Allocate cyboi service sleep time.
-    cyboi_service_sleep_time = (double*) malloc(*DOUBLE_PRIMITIVE_SIZE);
+    cyboi_service_sleep_time = (double*) malloc(*DOUBLE_REAL_TYPE_SIZE);
 
     //
     // Variable initialisation.
     //
 
-    // The internal memory count and size do not have to be initialised here,
-    // since they have already been initialised above, right at their declaration.
-    // Initialise knowledge memory count, size.
-    *kc = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    *ks = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    // Initialise signal memory count, size.
-    *sc = *NUMBER_0_INTEGER_MEMORY_MODEL;
-    *ss = *NUMBER_0_INTEGER_MEMORY_MODEL;
-
     // Initialise signal memory interrupt request flag.
     *signal_memory_irq = *NUMBER_0_INTEGER_MEMORY_MODEL;
     // Initialise gnu/linux console interrupt request flag.
@@ -252,20 +290,6 @@ void manage(void* p0, void* p1) {
     // Initialise cyboi service sleep time.
     *cyboi_service_sleep_time = *NUMBER_0_1_DOUBLE_MEMORY_MODEL;
 
-    //
-    // CAUTION! As an exception, the following allocations have to be done AFTER the sizes
-    // have been initialised above, since the sizes are used for allocation.
-    //
-
-    // Allocate internal memory.
-    // CAUTION! The internal memory size was declared as int (not int*) above,
-    // so that a reference needs to be handed over here!
-    allocate((void*) &i, (void*) &is, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
-    // Allocate knowledge memory.
-    allocate((void*) &k, (void*) ks, (void*) COMPOUND_MEMORY_ABSTRACTION, (void*) COMPOUND_MEMORY_ABSTRACTION_COUNT);
-    // Allocate signal memory.
-    allocate((void*) &s, (void*) ss, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
-
     //
     // System startup.
     //
@@ -287,6 +311,7 @@ void manage(void* p0, void* p1) {
     // For example, the tcp socket is running in an own thread.
     // Therefore, the knowledge memory and signal memory NEED TO BE ADDED
     // to the internal memory, in order to be forwardable to threads.
+
     startup_internal_memory(i,
         (void*) &k, (void*) &kc, (void*) &ks,
         (void*) &s, (void*) &sc, (void*) &ss,
@@ -304,7 +329,7 @@ void manage(void* p0, void* p1) {
     //
 
     // Initialise system with an initial signal.
-    initialise(i, s, (void*) sc, (void*) ss, p0, p1);
+    initialise(s, (void*) sc, (void*) ss, p0, p1, i);
 
     //
     // System shutdown.
@@ -383,15 +408,13 @@ void manage(void* p0, void* p1) {
     free((void*) cyboi_service_sleep_time);
 
     // Deallocate signal memory.
-    deallocate((void*) &s, (void*) ss, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
-    deallocate((void*) &sc, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    deallocate((void*) &ss, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+    deallocate_model((void*) &s, (void*) &sc, (void*) &ss, (void*) NUMBER_0_INTEGER_MEMORY_MODEL, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION, (void*) SIGNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
     // Deallocate knowledge memory.
-    deallocate((void*) &k, (void*) ks, (void*) COMPOUND_MEMORY_ABSTRACTION, (void*) COMPOUND_MEMORY_ABSTRACTION_COUNT);
-    deallocate((void*) &kc, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
-    deallocate((void*) &ks, (void*) PRIMITIVE_MEMORY_MODEL_COUNT, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION, (void*) INTEGER_VECTOR_MEMORY_ABSTRACTION_COUNT);
+    deallocate_model((void*) &k, (void*) &kc, (void*) &ks, (void*) NUMBER_0_INTEGER_MEMORY_MODEL, (void*) COMPOUND_MEMORY_ABSTRACTION, (void*) COMPOUND_MEMORY_ABSTRACTION_COUNT);
     // Deallocate internal memory.
-    deallocate((void*) &i, (void*) &is, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
+    // CAUTION! The internal memory count and size are set to a
+    // pre-defined value given by the constant "INTERNAL_MEMORY_MEMORY_MODEL_COUNT".
+    deallocate_model((void*) &i, (void*) &ic, (void*) &is, (void*) INTERNAL_MEMORY_MEMORY_MODEL_COUNT, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION, (void*) INTERNAL_MEMORY_MEMORY_ABSTRACTION_COUNT);
 }
 
 /* MANAGER_SOURCE */
