@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2009. Christian Heller.
+ * Copyright (C) 1999-2011. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,30 +19,28 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version $RCSfile: log_setting.c,v $ $Revision: 1.2 $ $Date: 2009/01/31 16:06:34 $ $Author: christian $
+ * @version $RCSfile: log_setting.c,v $ $Revision: 1.2 $ $Date: 2009-01-31 16:06:34 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef LOG_SETTING_SOURCE
 #define LOG_SETTING_SOURCE
 
+#include <stdio.h>
+
 //
 // CAUTION! Do NOT try to assign any values here!
-//
-// Ideally, of course, *NULL_POINTER_MEMORY_MODEL would be assigned as initial value.
-// But then, the compiler shows the following error:
+// Otherwise, the compiler shows the following error:
 // "error: initializer element is not constant"
-//
-// Therefore, the variables are only initialised in function "globalise"
-// of module "globaliser.c".
+// Therefore, the variables are only initialised in module "globaliser.c".
 //
 
 /** The log level. */
-static int* LOG_LEVEL;
+static signed char* LOG_LEVEL;
 
 /** The log message. */
 static wchar_t* LOG_MESSAGE;
-static int* LOG_MESSAGE_COUNT;
+static signed short int* LOG_MESSAGE_COUNT;
 
 /** The log output. */
 static FILE* LOG_OUTPUT;
